@@ -23,15 +23,15 @@ build_time_vars = {'ABIFLAGS': '',
  'BYTESTR_DEPS': '\\',
  'CC': 'x86_64-pc-linux-gnu-gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wsign-compare -DNDEBUG',
+ 'CFLAGS': '-Wsign-compare',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
- 'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=x86-64 -mtune=generic '
-                            '-Werror=odr -Werror=lto-type-mismatch '
-                            '-Werror=strict-aliasing -flto -ffat-lto-objects '
+ 'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=x86-64-v3 -Werror=odr '
+                            '-Werror=lto-type-mismatch -Werror=strict-aliasing '
+                            '-flto -ffat-lto-objects '
                             '-fno-semantic-interposition -flto '
                             '-fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
                             '-Wextra -Wno-unused-parameter '
@@ -64,7 +64,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-system-ffi' '--with-system-libmpdec' "
                 "'--with-platlibdir=lib' '--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
-                "'--without-assertions' '--enable-optimizations' "
+                "'--with-assertions' '--enable-optimizations' "
                 "'--with-readline=readline' '--without-valgrind' '--with-lto' "
                 "'build_alias=x86_64-pc-linux-gnu' "
                 "'host_alias=x86_64-pc-linux-gnu' "
@@ -626,15 +626,14 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.11',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.11',
- 'INSTALL': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
-            '-c',
- 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
-                 '-c -m 644',
- 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
+ 'INSTALL': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c',
+ 'INSTALL_DATA': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c '
+                 '-m 644',
+ 'INSTALL_PROGRAM': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.11.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
@@ -649,11 +648,10 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDEST': '/usr/lib/python3.11',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=x86-64 '
-                    '-mtune=generic -Werror=odr -Werror=lto-type-mismatch '
-                    '-Werror=strict-aliasing -flto -ffat-lto-objects '
-                    '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                    '-ffat-lto-objects -g -std=c11 -Wextra '
+ 'LIBEXPAT_CFLAGS': '-Wsign-compare -O2 -pipe -march=x86-64-v3 -Werror=odr '
+                    '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
+                    '-ffat-lto-objects -fno-semantic-interposition -flto '
+                    '-fuse-linker-plugin -ffat-lto-objects -g -std=c11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
                     '-fvisibility=hidden -fprofile-use -fprofile-correction '
@@ -665,11 +663,10 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 -Wsign-compare '
-                    '-DNDEBUG -O2 -pipe -march=x86-64 -mtune=generic '
-                    '-Werror=odr -Werror=lto-type-mismatch '
-                    '-Werror=strict-aliasing -flto -ffat-lto-objects '
-                    '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                    '-ffat-lto-objects -g -std=c11 -Wextra '
+                    '-O2 -pipe -march=x86-64-v3 -Werror=odr '
+                    '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
+                    '-ffat-lto-objects -fno-semantic-interposition -flto '
+                    '-fuse-linker-plugin -ffat-lto-objects -g -std=c11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
                     '-fvisibility=hidden -fprofile-use -fprofile-correction '
@@ -927,7 +924,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
- 'OPT': '-DNDEBUG',
+ 'OPT': '',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -967,9 +964,8 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=x86-64 '
-                             '-mtune=generic -Werror=odr '
-                             '-Werror=lto-type-mismatch '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -O2 -pipe -march=x86-64-v3 '
+                             '-Werror=odr -Werror=lto-type-mismatch '
                              '-Werror=strict-aliasing -flto -ffat-lto-objects '
                              '-fno-semantic-interposition -flto '
                              '-fuse-linker-plugin -ffat-lto-objects -g '
@@ -981,8 +977,8 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fprofile-correction -I./Include/internal -I. '
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wsign-compare -DNDEBUG',
- 'PY_CFLAGS_NODIST': '-O2 -pipe -march=x86-64 -mtune=generic -Werror=odr '
+ 'PY_CFLAGS': '-Wsign-compare',
+ 'PY_CFLAGS_NODIST': '-O2 -pipe -march=x86-64-v3 -Werror=odr '
                      '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
                      '-ffat-lto-objects -fno-semantic-interposition -flto '
                      '-fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
@@ -992,11 +988,10 @@ build_time_vars = {'ABIFLAGS': '',
                      '-fvisibility=hidden -fprofile-use -fprofile-correction '
                      '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=x86-64 '
-                   '-mtune=generic -Werror=odr -Werror=lto-type-mismatch '
-                   '-Werror=strict-aliasing -flto -ffat-lto-objects '
-                   '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                   '-ffat-lto-objects -g -std=c11 -Wextra '
+ 'PY_CORE_CFLAGS': '-Wsign-compare -O2 -pipe -march=x86-64-v3 -Werror=odr '
+                   '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
+                   '-ffat-lto-objects -fno-semantic-interposition -flto '
+                   '-fuse-linker-plugin -ffat-lto-objects -g -std=c11 -Wextra '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
                    '-fvisibility=hidden -fprofile-use -fprofile-correction '
@@ -1020,13 +1015,12 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=x86-64 '
-                        '-mtune=generic -Werror=odr -Werror=lto-type-mismatch '
-                        '-Werror=strict-aliasing -flto -ffat-lto-objects '
-                        '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                        '-ffat-lto-objects -g -std=c11 -Wextra '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
-                        '-Wstrict-prototypes '
+ 'PY_STDMODULE_CFLAGS': '-Wsign-compare -O2 -pipe -march=x86-64-v3 -Werror=odr '
+                        '-Werror=lto-type-mismatch -Werror=strict-aliasing '
+                        '-flto -ffat-lto-objects -fno-semantic-interposition '
+                        '-flto -fuse-linker-plugin -ffat-lto-objects -g '
+                        '-std=c11 -Wextra -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers -Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden -fprofile-use '
                         '-fprofile-correction -I./Include/internal -I. '
